bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.add_plate_axis
=====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.add_plate_axis